package Gm_Core;

###############################################################################
# Greymatter 1.6.1                            
# Copyright (c)2000-2006, The Greymatter team 
# http://greymatterforum.proboards82.com/     
# By possessing this software, you agree not to hold the author responsible for 
# any problems that may arise from your installation or usage of Greymatter 
# itself, or from any content generated by yourself or others through the use of 
# this program.  You <I>may</I> freely modify and redistribute this program, so 
# long as every copyright notice (including in this manual and in the Greymatter 
# code) remains fully intact.  Finally, you may <I>not</I> sell or in any way 
# make a financial profit from this program, either in original or modified form.
# Your possession of this software signifies that you agree to these terms; 
# please delete your copy of this software if you don't agree to these terms.
# Original Creators Noah Grey
###############################################################################

#==============================================================================
# Note no exporting because items from this package should be fully qualified
## Gm Core
# This package groups functions that deal with the core
# functionality of GreyMatter:
# - Amin screen functionality
# - 
#
# CONVENTIONS
# 1. Return a string rather than printing, this is just more elegant.  Leave prints
#   to the calling subroutine, if possible
# 2. Private subroutines should start with the '_' character.  By private I mean
#   it will never be called outside of this package.
# 3. If you have more than 1 or 2 parameters, especially if they are not required,
#   use named parameters such as in createRadioButton.  By putting stuff in a 
#   hash we gain the flexibility to add more optional parameters without having
#   to pass in '' placeholders or modify existing code.
# 4. Subs starting with 'create' should return a string.
# 5. Subs starting with 'display' are expected to contain print statements
# 6. Use ' and " where appropriate.  If you don't have any variables or newlines
# then use ', its quicker and cleaner.  
# 7. Don't put all text on one huge long line.  It messes with some programs
# that don't do line wraps.  

use strict;
use warnings;

use Gm_Utils qw( println );
use Gm_Constants;
use Gm_Storage;
use Gm_Web;

my $configs = Gm_Storage::getConfigs( errHandler=>\&Gm_Web::displayAdminErrorExit );

# ---------------
# write to cp log
# ---------------
## Write to Control Panel Log
# shorthand to write to the control panel log, used by admin
# or user, but must pass handler if want error to look right
# ARGS1 = message to write to control panel
# (opt) ARGS2 = error handler
# DEPRECATES: gm_writetocplog
sub writeToCplog {
	my $writetologtext = shift(@_);
	my $errHandler = shift(@_) || \&Gm_Web::displayAdminErrorExit;

	if ($configs->{'gmkeeplog'} eq Gm_Constants::YES) {
		my ($gmdate) = Gm_Utils::getStdDate( $configs->{'gmserveroffset'} );
		my $authorIp = $ENV{'REMOTE_ADDR'};
		if ($writetologtext =~ /<\?|<script|<%|<iframe/ ) {
			$writetologtext = "[Aborted log - Hack Attempt]";
		}
	
		Gm_Storage::addLogMessage( msg=>"<font size=\"1\">[$gmdate] [$authorIp]".
		"</font> $writetologtext",
		errHandler=>$errHandler );
	}
} 


1;
